@@ -128,6 +128,8 @@ def metamake_bin():
     """the actual metamake commandline tool (main function)"""
 
     import sys
+    import os
+    sys.path.insert(0, os.getcwd())
     import metamake
     import Makefile
     
