@@ -980,51 +980,51 @@ class loggable_path(path):
         ))
     
     def listdir(self, pattern = None):
-        self._log("listdir(pattern=%(pattern)s)" % locals())
+        self._log("listdir{pattern=%(pattern)s}" % locals())
         return path.listdir(self, pattern)
     
     def dirs(self, pattern = None):
-        self._log("dirs(pattern=%(pattern)s)" % locals())
+        self._log("dirs{pattern=%(pattern)s}" % locals())
         return path.dirs(self, pattern)
     
     def files(self, pattern = None):
-        self._log("files(pattern=%(pattern)s)" % locals())
+        self._log("files{pattern=%(pattern)s}" % locals())
         return path.files(self, pattern)
     
     def walk(self, pattern = None, errors = 'strict'):
-        self._log("walk(pattern=%(pattern)s, errors=%(errors)s)" % locals())
+        self._log("walk{pattern=%(pattern)s, errors=%(errors)s}" % locals())
         return path.walk(self, pattern, errors)
     
     def walkdirs(self, pattern = None, errors = 'strict'):
-        self._log("walkdirs(pattern=%(pattern)s, errors=%(errors)s)" % locals())
+        self._log("walkdirs{pattern=%(pattern)s, errors=%(errors)s}" % locals())
         return path.walkdirs(self, pattern, errors)
     
     def walkfiles(self, pattern = None, errors = 'strict'):
-        self._log("walkfiles(pattern=%(pattern)s, errors=%(errors)s)" % locals())
+        self._log("walkfiles{pattern=%(pattern)s, errors=%(errors)s}" % locals())
         return path.walkfiles(self, pattern, errors)
     
     def fnmatch(self, pattern = None):
-        self._log("fnmatch(pattern=%(pattern)s)" % locals())
+        self._log("fnmatch{pattern=%(pattern)s}" % locals())
         return path.fnmatch(self, pattern)
     
     def glob(self, pattern = None):
-        self._log("glob(pattern=%(pattern)s)" % locals())
+        self._log("glob{pattern=%(pattern)s}" % locals())
         return path.glob(self, pattern)
     
     def open(self, mode = 'r'):
-        self._log("open(mode=%(mode)s)" % locals())
+        self._log("open{mode=%(mode)s}" % locals())
         return path.open(self, mode)
     
     def write_bytes(self, bytes, append = False):
-        self._log("write_bytes(append=%(append)s)" % locals())
+        self._log("write_bytes{append=%(append)s}" % locals())
         return path.write_bytes(self, bytes, append)
     
     def write_text(self, text, encoding=None, errors='strict', linesep=os.linesep, append=False):
-        self._log("write_text(errors=%(errors)s, append=%(append)s)" % locals())
+        self._log("write_text{errors=%(errors)s, append=%(append)s}" % locals())
         return path.write_text(self, text, encoding, errors, linesep, append)
 
     def write_lines(self, lines, encoding=None, errors='strict', linesep=os.linesep, append=False):
-        self._log("write_lines(errors=%(errors)s, append=%(append)s)" % locals())
+        self._log("write_lines{errors=%(errors)s, append=%(append)s}" % locals())
         return path.write_lines(self, lines, encoding, errors, linesep, append)
 
     def read_md5(self):
@@ -1056,31 +1056,31 @@ class loggable_path(path):
         return path.samefile(self)
     
     def access(self, mode):
-        self._log("access?(mode=%(mode)s)" % locals())
+        self._log("access?{mode=%(mode)s}" % locals())
         return path.access(self, mode)
     
     def chmod(self, mode):
-        self._log("chmod(mode=%(mode)s)" % locals())
+        self._log("chmod{mode=%(mode)s}" % locals())
         return path.chmod(self, mode)
     
     def chown(self, uid, gid):
-        self._log("chown(uid=%(uid)s, gid=%(gid)s)" % locals())
+        self._log("chown{uid=%(uid)s, gid=%(gid)s}" % locals())
         return path.chown(self, uid, gid)
 
     def rename(self, new):
-        self._log("rename(new=%(new)s)" % locals())
+        self._log("rename{new=%(new)s}" % locals())
         return path.rename(self, new)
 
     def renames(self, new):
-        self._log("renames(new=%(new)s)" % locals())
+        self._log("renames{new=%(new)s}" % locals())
         return path.renames(self, new)
 
     def mkdir(self, mode=0777):
-        self._log("mkdir(mode=%(mode)s)" % locals())
+        self._log("mkdir{mode=%(mode)s}" % locals())
         return path.mkdir(self, mode)
 
     def makedirs(self, mode=0777):
-        self._log("makedirs(mode=%(mode)s)" % locals())
+        self._log("makedirs{mode=%(mode)s}" % locals())
         return path.makedirs(self, mode)
 
     def rmdir(self):
@@ -1103,39 +1103,39 @@ class loggable_path(path):
         return path.unlink(self)
     
     def link(self, newpath):
-        self._log("link(newpath=%(newpath)s)" % locals())
+        self._log("link{newpath=%(newpath)s}" % locals())
         return path.link(self, newpath)
     
     def symlink(self, newlink):
-        self._log("symlink(newlink=%(newlink)s)" % locals())
+        self._log("symlink{newlink=%(newlink)s}" % locals())
         return path.symlink(self, newlink)
         
     def copyfile(self, dst):
-        self._log("copyfile(dst=%(dst)s)" % locals())
+        self._log("copyfile{dst=%(dst)s}" % locals())
         return path.copyfile(self, dst)
         
     def copymode(self, dst):
-        self._log("copymode(dst=%(dst)s)" % locals())
+        self._log("copymode{dst=%(dst)s}" % locals())
         return path.copymode(self, dst)
         
     def copystat(self, dst):
-        self._log("copystat(dst=%(dst)s)" % locals())
+        self._log("copystat{dst=%(dst)s}" % locals())
         return path.copystat(self, dst)
         
     def copy(self, dst):
-        self._log("copy(dst=%(dst)s)" % locals())
+        self._log("copy{dst=%(dst)s}" % locals())
         return path.copy(self, dst)
         
     def copy2(self, dst):
-        self._log("copy2(dst=%(dst)s)" % locals())
+        self._log("copy2{dst=%(dst)s}" % locals())
         return path.copy2(self, dst)
         
     def copytree(self, dst, symlinks=None):
-        self._log("copytree(dst=%(dst)s, symlinks=%(symlinks)s)" % locals())
+        self._log("copytree{dst=%(dst)s, symlinks=%(symlinks)s}" % locals())
         return path.copytree(self, dst, symlinks)
         
     def move(self, dst):
-        self._log("move(dst=%(dst)s)" % locals())
+        self._log("move{dst=%(dst)s}" % locals())
         return path.move(self, dst)
         
     def rmtree(self, ignore_errors=None, onerror=None):
